# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/restaurant/instagram/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Restaurant\\Instagram\\": "packages/restaurant/instagram/src",
            "Restaurant\\Instagram\\Seeders\\": "packages/restaurant/instagram/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Restaurant\Instagram\Providers\InstagramServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Instagram'  => Restaurant\Instagram\Facades\Instagram::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Restaurant\\Instagram\\Seeders\\InstagramTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Restaurant\Instagram\Providers\InstagramServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Restaurant\Instagram\Providers\InstagramServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Restaurant\Instagram\Providers\InstagramServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/instagram/{modulename}

**User**

    http://path-to-route-folder/user/instagram/{modulename}

**Public**

    http://path-to-route-folder/instagrams


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/instagram/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/instagram/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/instagram/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/instagram/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/instagram/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/instagram/{modulename}/{slug}
    METHOD: GET