<?php

namespace Restaurant\Instagram\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Restaurant\Instagram\Models\InstagramCampaign;

class InstagramCampaignPolicy
{

    /**
     * Determine if the given user can view the instagram_campaign.
     *
     * @param UserPolicyInterface $authUser
     * @param InstagramCampaign $instagram_campaign
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, InstagramCampaign $instagram_campaign)
    {
        if ($authUser->canDo('instagram.instagram_campaign.view') && $authUser->isAdmin()) {
            return true;
        }

        return $instagram_campaign->user_id == user_id() && $instagram_campaign->user_type == user_type();
    }

    /**
     * Determine if the given user can create a instagram_campaign.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('instagram.instagram_campaign.create');
    }

    /**
     * Determine if the given user can update the given instagram_campaign.
     *
     * @param UserPolicyInterface $authUser
     * @param InstagramCampaign $instagram_campaign
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, InstagramCampaign $instagram_campaign)
    {
        if ($authUser->canDo('instagram.instagram_campaign.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $instagram_campaign->user_id == user_id() && $instagram_campaign->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given instagram_campaign.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, InstagramCampaign $instagram_campaign)
    {
        return $instagram_campaign->user_id == user_id() && $instagram_campaign->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given instagram_campaign.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, InstagramCampaign $instagram_campaign)
    {
        if ($authUser->canDo('instagram.instagram_campaign.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given instagram_campaign.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, InstagramCampaign $instagram_campaign)
    {
        if ($authUser->canDo('instagram.instagram_campaign.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
