<?php

namespace Restaurant\Instagram\Providers;

use Illuminate\Support\ServiceProvider;
use Restaurant\Instagram\Instagrams;

class InstagramServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'instagram');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'instagram');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        // $this->registerCommands();

        $this->app->register(\Restaurant\Instagram\Providers\AuthServiceProvider::class);
        $this->app->register(\Restaurant\Instagram\Providers\RouteServiceProvider::class);
        // $this->app->register(\Restaurant\Instagram\Providers\EventServiceProvider::class);
        // $this->app->register(\Restaurant\Instagram\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('restaurant.instagram', function($app)
        {
            return $this->app->make(Instagrams::class);
        });
    }



    /**
     * Merges user's and instagram's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'restaurant.instagram'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/instagram_campaign.php', 'restaurant.instagram.instagram_campaign'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Restaurant\Instagram\Commands\Instagram::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['restaurant.instagram'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('restaurant/instagram')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/instagram')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/instagram')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
